from .api import UmiPy
from .enums import Prefix, BalanceType
from . import bech32
from .helpers import get_address_prefix
from .models import BalanceResponse, TransactionResponse

__all__ = (
    UmiPy,
    Prefix,
    BalanceType,
    bech32,
    get_address_prefix,
    BalanceResponse,
    TransactionResponse,
)



import enum


class BalanceType(enum.StrEnum):
    confirmed = "confirmedBalance"
    unconfirmed = "unconfirmedBalance"


class Encoding(enum.Enum):
    """Enumeration type to list the various supported encodings."""

    BECH32 = 1
    BECH32M = 2


class Prefix(enum.StrEnum):
    UMI = "umi"
    GLIZE = "glz"
    GLIZE_STAKING = "gls"

    ROD_TRADING = "rod"

    UMI_STAKING = "umistake"
    UMI_TRADING = "umitrade"

    # parturiunt montes nascetur ridiculus mus
    DOSTATOK = "rod01"
    MOSHKIN = "rod02"
    ELTSYN = "rod03"
    PECHANSKAIA = "rod04"
    KOSTENKO = "rod05"
    BUKHVOSTOV = "rod06"
    SEDINKIN = "rod07"
    KABAKOV = "rod08"
    BONDAR = "rod09"
    SHIHOFF = "rod10"
    TITOV = "rod11"
    LARIN = "rod12"
    GUZMAN = "rod13"
    TORSHIN = "rod14"
    BUTYREV = "rod15"
    BARYBINA = "rod16"
    STRELNIKOV = "rod17"
    PYASTUN = "rod18"
    NEKRASOV = "rod19"
    YAHONT = "rod20"
    MALOVA = "rod21"
    MAZANOVA = "rod22"
    TOKAREV = "rod23"
    GRISHIN = "rod24"
    SHILOVA = "rod25"
    KARAPETIAN = "rod26"
    SARTAEVA = "rod27"
    MEDVED = "rod28"
    ALADYSHKIN = "rod29"
    STAROSTENKO = "rod30"
    GORLIAK = "rod31"
    KONDRATIUK = "rod32"
    VILAVI = "rod33"
    UMIROD = "rod34"
    GLIZEROD = "rod35"
    ROD_WALK = "rod36"
    MILLIONER = "rod37"
    ROD_38 = "rod38"
    ROD_39 = "rod39"
    ROD_40 = "rod40"
    ROD_41 = "rod41"
    ROD_42 = "rod42"
    ROD_43 = "rod43"
    ROD_44 = "rod44"
    ROD_45 = "rod45"
    ROD_46 = "rod46"
    ROD_47 = "rod47"
    ROD_48 = "rod48"
    ROD_49 = "rod49"
    ROD_50 = "rod50"
    ROD_51 = "rod51"
    ROD_52 = "rod52"
    ROD_53 = "rod53"
    ROD_54 = "rod54"
    ROD_55 = "rod55"
    ROD_56 = "rod56"
    ROD_57 = "rod57"
    ROD_58 = "rod58"
    ROD_59 = "rod59"
    ROD_60 = "rod60"
    ROD_61 = "rod61"
    ROD_62 = "rod62"
    ROD_63 = "rod63"
    ROD_64 = "rod64"
    ROD_65 = "rod65"
    ROD_66 = "rod66"
    ROD_67 = "rod67"
    ROD_68 = "rod68"
    ROD_69 = "rod69"
    ROD_70 = "rod70"
    ROD_71 = "rod71"
    ROD_72 = "rod72"
    ROD_73 = "rod73"
    ROD_74 = "rod74"
    ROD_75 = "rod75"
    ROD_76 = "rod76"
    ROD_77 = "rod77"
    ROD_78 = "rod78"
    ROD_79 = "rod79"
    ROD_80 = "rod80"
    ROD_81 = "rod81"
    ROD_82 = "rod82"
    ROD_83 = "rod83"
    ROD_84 = "rod84"
    ROD_85 = "rod85"
    ROD_86 = "rod86"
    ROD_87 = "rod87"
    ROD_88 = "rod88"
    ROD_89 = "rod89"
    ROD_90 = "rod90"
    ROD_91 = "rod91"
    ROD_92 = "rod92"
    ROD_93 = "rod93"
    ROD_94 = "rod94"
    ROD_95 = "rod95"
    ROD_96 = "rod96"
    ROD_97 = "rod97"
    ROD_98 = "rod98"
    ROD_99 = "rod99"
